/*
*  Boilerplate code for creating computed data bindings
*/
document.addEventListener('gc-databind-ready', function() 
{
    /* 
	*   Add custom computed value databindings here, using the following method:
	*
    *   function gc.databind.registry.bind(targetBinding, modelBinding, [getter], [setter]);
	*
	*   param targetBinding - single binding string or expression, or array of binding strings for multi-way binding.
	*   param modelBinding - single binding string or expression, or array of binding strings for multi-way binding.
	*   param getter - (optional) - custom getter function for computing the targetBinding value(s) based on modelBinding value(s).
	*   param setter - (optional) - custom setter function for computing the modelBinding value(s) based on targetBinding value(s).
    */
	
	// For example, a simple computed values based on simple expression
	// gc.databind.registry.bind('widget.id.propertyName', "targetVariable == 1 ? 'binding is one' : 'binding is not one'");
	
	// Or a custom two-way binding with custome getter and setter functions.  (setter is optional)  (getter only indicates one-way binding)
	// gc.databind.registry.bind('widget.id.propertyName', "targetVariable", function(value) { return value*5/9 + 32; }, function(value) { (return value-32)*9/5; });
	
	// Event 1 to n bindings
	/* 
    gc.databind.registry.bind('widget.date.value', 
        // dependant bindings needed in order to compute the date, in name/value pairs.
        {
            weekday: 'widget.dayOfWeek.selectedText',
            day: 'widget.dayOfMonth.value',
            month: 'widget.month.selectedText',
            year: 'widget.year.value'
        }, 
        // getter for date computation
        function(values) 
        {
            // compute and return the string value to bind to the widget with id 'date'
            return values.weekday + ', ' + values.month + ' ' + values.day + ', ' + values.year;
        }
    ); 
	*/
});

    var setTemperatureScale = function(tempScale){
        var celsius = false;
        var farenheit = false
        var kelvin = false;
        switch (tempScale){

            case 'F': farenheit = true; break;
            case 'C': celsius = true; break;
            case 'K': kelvin = true; break;
        }
        document.getElementById("celsiusMenuAction").checked = celsius;
        document.getElementById("farenheitMenuAction").checked = farenheit;
        document.getElementById("kelvinMenuAction").checked = kelvin;
        
        document.getElementById("ti_widget_temperaturegraph").temperatureScale = tempScale;
        document.getElementById("ti_widget_label_tempscale").label = tempScale;

    }

    var openLink = function(link){
		var isNodeWebkit = (typeof process !== undefined);
	    if (isNodeWebkit) {
	        // open link with default browser
	       var gui = require('nw.gui');
           gui.Shell.openExternal(link);
        } else {
            // open link in a new window
           window.open(link);
		}
    }


/*
*  Boilerplate code for creating custom actions
*/
document.addEventListener('gc-nav-ready', function() 
{
    /* 
	*   Add custom actions for menu items using the following api:
	*
    *   function gc.nav.registryAction(id, runable, [isAvailable], [isVisible]);
	*
	*   param id - uniquely identifies the action, and should correspond to the action property of the menuaction widget.
	*   param runable - function that performs the custom action.
	*   param isAvailable - (optional) - function called when the menu action is about to appear.  Return false to disable the action, or true to enable it.
	*   param isVisible - (optional) - function called when the menu action is about to appear.  Return false to hide the action, or true to make it visible.
    */
	
	// For example,
	// gc.nav.registerAction('myCustomCloseAction', function() { window.close(); }, function() { return true; }, function() { return true; });
	
	// Alternatively, to programmatically disable a menu action at any time use:
	// gc.nav.disableAction('myCustomCloseAction);    then enable it again using:  gc.nav.enableAction('myCustomCloseAction'); 

	gc.nav.registerAction('kelvinMenuAction',function(){setTemperatureScale('K');},function() {return true;}, function(){ return true;});
	gc.nav.registerAction('farenheitMenuAction',function(){setTemperatureScale('F');},function() {return true;}, function(){ return true;});
	gc.nav.registerAction('celsiusMenuAction',function(){setTemperatureScale('C');},function() {return true;}, function(){ return true;});
	gc.nav.registerAction('onlineHelpAction',function(){openLink("http://processors.wiki.ti.com/index.php/TI_Cloud_Agent_Troubleshooting_Guide");},function() {return true;}, function(){ return true;});
	gc.nav.registerAction('e2eAction',function(){openLink("http://e2e.ti.com/support/development_tools/code_composer_studio/");},function() {return true;}, function(){ return true;});
});

/*
*  Boilerplate code for working with components in the application gist
*/
var initComplete = false;
var templateObj; // need to wait for WebComponentsReady event before getting element
   

var init = function() {
    templateObj = document.querySelector('#template_obj');
    
    templateObj.imageIndex = 0;
    templateObj.selectedDeviceIndex = 0;
    templateObj.isRunning = false;
    templateObj.backplane = undefined;
    templateObj.serialio = undefined;
    templateObj.programLoader = undefined;
    templateObj.shared_temperatureScale = "C";
    templateObj.shared_temperature = 20;
    templateObj.shared_currentTemperature = 20;
    templateObj.shared_isConnectedToCloudAgent = false;
    // TODO: need to listen to  $.target_device.serialIO.backplane.isConnectedToCloudAgent  and update the above.
	
    templateObj.btnVisibilityChangedHdlr = function(){
        if (templateObj.backplane.isConnectBtnVisible) {
            templateObj.$.ti_widget_temperaturegraph.isHidden = true;
            templateObj.$.ti_widget_multiimage.selectedIndex = 0;
            templateObj.$.ti_widget_multiimage.disabled = true;
        }

        if (templateObj.backplane.isDisconnectBtnVisible) {
            templateObj.$.ti_widget_multiimage.selectedIndex = 0;
        }

    };
 
    templateObj.programDownloadUIVisibilityChangedHdlr = function() {
        if (templateObj.programLoader.isProgramDownloadBtnVisible) {
            templateObj.$.ti_widget_multiimage.selectedIndex = 1;
            templateObj.$.ti_widget_multiimage.disabled = false;
        }
    };
 
    templateObj.onReceivingDataHdlr = function() {
        templateObj.$.ti_widget_multiimage.selectedIndex = 0;
        templateObj.$.ti_widget_temperaturegraph.isHidden = false;
        templateObj.$.ti_widget_multiimage.disabled = false;
    };
    
	templateObj.backplaneChanged = function(){
	     // to access a widget with an id of 'widget_id', use templateObj.$.widgetId 
	         if (templateObj.backplane) {
                templateObj.backplane.removeEventListener("btnVisibilityChanged", templateObj.btnVisibilityChangedHdlr);
	         }
    	     templateObj.backplane = gc.services['ti-core-backplane'];
             templateObj.backplane.addEventListener("btnVisibilityChanged", templateObj.btnVisibilityChangedHdlr);
             if (templateObj.serialio) {
                 templateObj.serialio.removeEventListener("serialPortUIVisibilityChanged",templateObj.serialPortVisibilityChangedHdlr);
             }
             templateObj.serialio = gc.services['ti-service-serialio']
             templateObj.serialio.addEventListener("serialPortUIVisibilityChanged",templateObj.serialPortVisibilityChangedHdlr);
             
             if (templateObj.programLoader) {
                 templateObj.programLoader.removeEventListener("programDownloadUIVisibilityChanged",templateObj.programDownloadUIVisibilityChangedHdlr);
             }
             templateObj.programLoader = gc.services['ti-service-programloader'];
             templateObj.programLoader.backplane = templateObj.backplane;
             templateObj.programLoader.addEventListener("programDownloadUIVisibilityChanged",templateObj.programDownloadUIVisibilityChangedHdlr);
             templateObj.$.target_device.addEventListener("serialioModelReceivingData",templateObj.onReceivingDataHdlr);
             templateObj.$.ti_widget_multiimage.disabled = true;
	};
    
	templateObj.addEventListener('dom-change',function(){
	    if (initComplete) return;
	    this.async(function(){
    	    initComplete = true;
    	    gc = gc || {};
    	    gc.services = gc.services || {};
    	    templateObj.backplane = gc.services['ti-core-backplane'];
    	    if (templateObj.backplane) {
    	        templateObj.backplaneChanged();
    	    }
    	    document.addEventListener('ti-core-backplane-ready',templateObj.backplaneChanged);
        },1);
	
	});
	
	if (templateObj.$) {
	    templateObj.attached();
	}
};

templateObj = document.querySelector('#template_obj');
if (templateObj) {
    init();
} else {
    document.addEventListener('DOMContentLoaded',init.bind(this))
} 